pub struct MockLicensesApi {
LicensesApi_expectations: MockLicensesApi_LicensesApi,
}Fields
LicensesApi_expectations: MockLicensesApi_LicensesApiImplementations
Sourceimpl MockLicensesApi
impl MockLicensesApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockLicensesApi
impl MockLicensesApi
Sourcepub fn expect_get_user(&mut self) -> &mut Expectation
pub fn expect_get_user(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_user method
Sourcepub fn expect_organization_sync(&mut self) -> &mut Expectation
pub fn expect_organization_sync(&mut self) -> &mut Expectation
Create an Expectation for mocking the organization_sync method